/*
 * vfread.c version 2.0 part of the vfloppy 2.0 package
 *
 * This version delivered in 2010 by Fred Jan Kraan (fjkraan@xs4all.nl)
 *
 * vfread is placed under the GNU General Public License in March 2010.
 *
 *  This file is part of Vfloppy 2.0.
 *
 *  Vfloppy is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Vfloppy is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Vfloppy; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

/*
 * vfread - two modes; 
 *   without fileName, the directory of the image is displayed
 *   with fileName, the file is extracted fromthe image
 * 
 * vfread <imageName> [<fileName>]
 */

#include <string.h>
#include <ctype.h>
#include <stdlib.h>
#include <unistd.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <stdio.h>
#include <fcntl.h>
#include "vf.h"

int debug = 0;

int main(int argc,char **argv)
{	
	argData_t *pArgData = &argData;
	parseArgs(argc, argv, pArgData);
	debug = pArgData->debug;
		
	if (pArgData->imageName == NULL)
	{
		fprintf(stderr, "%s <imageName> [<fileName>]\n", argv[0]);
		fprintf(stderr, "vfread 2.0 (c)2010 F.J. Kraan\n");
		exit(1);
	}

	imageData_t *pImageData = &imageData;
	pImageData->fileName = pArgData->imageName;
	pImageData->file = 0;
	
	if (checkFileExistance(pImageData->fileName) == 0) 
	{
		fprintf(stderr," %s does not exists, exiting\n", pImageData->fileName);
		exit(1);
	}	
	
	if (pArgData->fileName == NULL)
	{
		if (debug > 0) printf("main; directory mode: reading %s\n", pImageData->fileName);
		
		pImageData->file = openFileRO(pImageData->fileName);
		
		printDirectory(pImageData->file);
		
		fclose(pImageData->file);
		
		exit(0);
	}
	if (checkFileExistance(pArgData->fileName) == 1) 
	{
		fprintf(stderr," %s already exists, exiting\n", argv[2]);
		exit(1);
	}
	
	// Convenient pointerized alias
	fileData_t *pFileData = &fileData;
	fileDataInit(pFileData);
	
	pFileData->fileName = (unsigned char*)pArgData->fileName;

	if (debug > 0) printf("main; file copy mode: retrieving %s from %s\n", pFileData->fileName, pImageData->fileName);
	
	convertFileName(pFileData);
	
	pImageData->file = openFileRO(pImageData->fileName);
	
	findFileExtends(pImageData->file, pFileData);
	
	if (pFileData->found == 1)
	{	
		findFileBlocks(pImageData->file, pFileData);
		
		createFile(pImageData->file, pFileData);
	}
	else
		printf("main; file '%s' not found in %s\n", pFileData->fileName, pImageData->fileName);
	
	fclose(pImageData->file);
	
	exit(0);
}


