/*
 * vfwrite.c version 2.0 part of the vfloppy 2.0 package
 *
 * This version delivered in 2010 by Fred Jan Kraan (fjkraan@xs4all.nl)
 *
 * vfwrite is placed under the GNU General Public License in March 2010.
 *
 *  This file is part of Vfloppy 2.0.
 *
 *  Vfloppy is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Vfloppy is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Vfloppy; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

/*
 * vfwrite - writes a file to the image imageName
 * 
 * vfwrite <imageName> <fileName>
 */

#include <string.h>
#include <ctype.h>
#include <stdlib.h>
#include <unistd.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <stdio.h>
#include <fcntl.h>
#include "vf.h"

int debug = 0;

int main(int argc,char **argv)
{	
	argData_t *pArgData = &argData;
	parseArgs(argc, argv, pArgData);
	debug = pArgData->debug;
	
	if (pArgData->imageName == NULL || pArgData->fileName == NULL)
	{
		fprintf(stderr, "%s <imageName> <fileName>\n", argv[0]);
		fprintf(stderr, "vfwrite 2.0 (c)2010 F.J. Kraan\n");
		exit(1);
	}

	if (checkFileExistance(pArgData->imageName) == 0)
	{
		printf("Image '%s' not found, exiting.\n", argv[1]);
	}
	char *imageName = pArgData->imageName;
	FILE *imageFile = NULL;
	
	if (checkFileExistance(pArgData->fileName) == 0)
	{
		printf("File '%s' not found, exiting.\n", argv[2]);
	}
	fileData_t *pFileData = &fileData;
	fileDataInit(pFileData);

	pFileData->fileName = (unsigned char*)pArgData->fileName;
	
	imageFile = openFileRW(imageName);	// open image
//	printf("main; imageFile: %p, \n", imageFile);
	convertFileName(pFileData);
	pFileData->fileSize = getFileSize(pFileData);
	
	findFileExtends(imageFile, pFileData);
	findFileBlocks(imageFile, pFileData);
	pFileData->file = openFileRO((char *)pFileData->fileName);	// open file

	int freeBlocks = getFreeBlockCount(imageFile);
	int freeExtends = getFreeDirectorySpace(imageFile);
	
	if (debug > 1) printf("main; freeBlocks: %X, newFileBlocks: %X, fileInImageBlocks: %X\n", 
	       freeBlocks, getSizeInBlocks(pFileData->fileSize), getImageFileBlockCount(pFileData));
	if (debug > 1) printf("main; freeExtends: %X, newFileExtends: %X, fileInImageExtends: %X\n",
	       freeExtends, getSizeInExtends(pFileData->fileSize), getImageFileExtendCount(pFileData));
	       
	int netBlocks  = 
		freeBlocks  - getSizeInBlocks(pFileData->fileSize)  + getImageFileBlockCount(pFileData);
	int netExtends = 
		freeExtends - getSizeInExtends(pFileData->fileSize) + getImageFileExtendCount(pFileData);
	
	if (netBlocks > 0 && netExtends > 0) 
	{
		if (debug > 0) printf("main; enough free blocks & extends.\n");
	} 
	else
	{
		printf("main; not enough space for file in image. Net blocks: %d, Net Extends: %d\n",
		       netBlocks, netExtends);
		
		exit(2);
	}
	if (pFileData->found == 1) 
	{
		if (debug > 1) printf("main; imageFile: %p, pFileData: %p\n", imageFile, pFileData);
		eraseFile(imageFile, pFileData);
	}
	fileDataInit(pFileData);
	convertFileName(pFileData);  // reinstates CP/M filename in pFileData->cpmFileName
	findUnusedBlocksExtends(imageFile, pFileData);
	writeDirectory(imageFile, pFileData);
	writeFile(imageFile, pFileData);
	fclose(imageFile);		// close image
	fclose(pFileData->file);	// close file
	return 0;
}
